==============
Sample Scripts
==============

Some sample scripts to illustrate the use of eppy and to show some common use cases. Later if these scripts are useful, they may be incorporated into the eppy API.

:Question: Why is this page empty?
:Answer: Give us time, we just started doing this

Running the preprocessor
------------------------

TODO (opened in `issue 387 <https://github.com/santoshphilip/eppy/issues/387>`_)
